<html>

<head>
  <title>{{app_title}}</title>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <style>
    .container {
      font-family: Arial, sans-serif;
      margin: 0 auto;
      max-width: 800px;
      padding: 50px;
      border-radius: 10px;
      border: 1px solid #ccc;
      margin: 20px auto;
    }

    h1 {
      font-size: 24px;
      margin-bottom: 20px;
    }

    p {
      padding: 0px;
      margin: 4px;
      line-height: 1.5rem;
    }

    @media (max-width: 600px) {
      .container {
        padding: 20px;
        border: none;
        margin: 0;
        max-width: 100%;
        border-radius: 0;
      }

      h1 {
        font-size: 20px;
        margin-bottom: 15px;
      }
    }
  </style>
</head>


<body>
  <div class="container">
    {{html_content | safe}}
  </div>
</body>

</html>
