<html>

<head>
  <title>Data removal request</title>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <script src="https://cdn.tailwindcss.com"></script>

</head>


<body>
  <div class="mx-auto m-16 max-w-lg">

    <h1 class="my-6 text-2xl">{{app_title}} Data removal request</h1>
    <p class="text-gray-600 text-sm">Please submit the form below in order to request complete removal of all
      data associated with your account. We'll be in touch by email to confirm that
      you are the owner of this data, and once confirmed, all your data will be removed permanently.
    </p>


    <form class="my-10 flex flex-col gap-1" action="/webpages/data-removal-request" method="post">
      <label class="mt-3 text-gray-500" for="name">Name</label>
      <input placeholder="Enter your name..." class="p-3 outline outline-1 outline-gray-400 rounded-lg" name="name" required />

      <label class="mt-3 text-gray-500" for="email">Email </label>
      <input type="email" placeholder="Enter your email address..." class="p-3 outline outline-1 outline-gray-400 rounded-lg" name="email" required />

      <label class="mt-3 text-gray-500" for="message">Message </label>
      <textarea class="p-3 text-gray-500 outline outline-1 outline-gray-400 rounded-lg" name="message" rows="10" required>
Dear {{app_title}} team,

I am writing to request the deletion of all my personal data associated with my account.Please remove all information, including but not limited to my account details, personal information, and any activity logs.

Thank you for your prompt attention to this matter.</textarea>

      <button class="bg-blue-500 text-white p-2 w-full rounded-lg mt-3">Submit</button>
    </form>


</body>

</html>
