<html>

<head>
  <title>Data removal request</title>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <script src="https://cdn.tailwindcss.com"></script>
</head>


<body>
  <div class="mx-auto m-16 max-w-lg">

    <h1 class="my-6 text-2xl">Thank you!</h1>
    <p class="text-gray-600">Your request to remove your data has been submitted.
      We'll be in touch with you by email very shortly.
    </p>

</body>

</html>
